@@ -9,7 +9,7 @@
 #ifndef _MISC_H
 #define _MISC_H
 
-typedef int (* outfuntype)(int);
+/* typedef int (* outfuntype)(int); */		/* Now in termcap.h */
 
 extern void err (const char *fmt, ...);
 
