@@ -154,7 +154,7 @@ reset_mode()
 void
 set_control_chars()
 {
-	char *bp, *p, bs_char, buf[1024];
+	char *bp, *p, bs_char, buf[TERMCAP_BUFSIZE];
 
 	bp = buf;
 	p = tgetstr("kb", &bp);
@@ -247,7 +247,7 @@ set_tabs()
 	int c;
 	char *capsp, *clear_tabs;
 	char *set_column, *set_pos, *set_tab, *tg_out;
-	char caps[1024];
+	char caps[TERMCAP_BUFSIZE];
 
 	capsp = caps;
 	set_tab = tgetstr("st", &capsp);
@@ -288,7 +288,7 @@ set_tabs()
 void
 set_init()
 {
-	char *bp, buf[1024];
+	char *bp, buf[TERMCAP_BUFSIZE];
 	int settle;
 
 	bp = buf;
@@ -314,6 +314,17 @@ set_init()
 			cat(buf);
 			settle = 1;
 		}
+	} else {	/* initialize ! */
+		bp = buf;
+		if (tgetstr("is", &bp) != 0) {
+			tputs(buf, 0, (outfuntype) outc);
+			settle = 1;
+		}
+		bp = buf;
+		if (tgetstr("if", &bp) != 0) {
+			cat(buf);
+			settle = 1;
+		}
 	}
 
 	if (settle) {
